==> SomeWithImage-0.1.1.crate: SomeWithImage-0.1.1/src/multiply_by_matrix/Filter.rs <==
pub struct Filter_matrix {
    pub matrix: Vec<Vec<i16>>,
    pub extra_value: i16,
}

impl Filter_matrix {
    pub fn create_matrix_3x3(filter_matrix: [[i16; 3]; 3], extra_value: i16) -> Filter_matrix {
        let mut matrix: Vec<Vec<i16>> = Vec::new();

        for i in 0..3 {
            let mut vec: Vec<i16> = Vec::new();
            for j in 0..3 {
                vec.push(filter_matrix[i][j]);
            }
            matrix.push(vec.clone());
        }

        Filter_matrix {
            matrix: matrix,
            extra_value: extra_value,
        }
    }

    pub fn create_matrix_5x5(filter_matrix: [[i16; 5]; 5], extra_value: i16) -> Filter_matrix {
        let mut matrix: Vec<Vec<i16>> = Vec::new();

        for i in 0..5 {
            let mut vec: Vec<i16> = Vec::new();
            for j in 0..5 {
                vec.push(filter_matrix[i][j]);
            }
            matrix.push(vec.clone());
        }

        Filter_matrix {
            matrix: matrix,
            extra_value: extra_value,
        }
    }

    pub fn create_matrix_7x7(filter_matrix: [[i16; 7]; 7], extra_value: i16) -> Filter_matrix {
        let mut matrix: Vec<Vec<i16>> = Vec::new();

        for i in 0..7 {
            let mut vec: Vec<i16> = Vec::new();
            for j in 0..7 {
                vec.push(filter_matrix[i][j]);
            }
            matrix.push(vec.clone());
        }

        Filter_matrix {
            matrix: matrix,
            extra_value: extra_value,
        }
    }
}

==> SomeWithImage-0.1.8.crate: SomeWithImage-0.1.8/src/multiply_by_matrix/Filter.rs <==
pub struct Filter_matrix {
    pub matrix: Vec<Vec<i16>>,
    pub extra_value: f32,
}

impl Filter_matrix {
    pub fn create_matrix_3x3(filter_matrix: [[i16; 3]; 3], extra_value: f32) -> Filter_matrix {
        let mut matrix: Vec<Vec<i16>> = Vec::new();

        for i in 0..3 {
            let mut vec: Vec<i16> = Vec::new();
            for j in 0..3 {
                vec.push(filter_matrix[i][j]);
            }
            matrix.push(vec.clone());
        }

        Filter_matrix {
            matrix: matrix,
            extra_value: extra_value,
        }
    }

    pub fn create_matrix_5x5(filter_matrix: [[i16; 5]; 5], extra_value: f32) -> Filter_matrix {
        let mut matrix: Vec<Vec<i16>> = Vec::new();

        for i in 0..5 {
            let mut vec: Vec<i16> = Vec::new();
            for j in 0..5 {
                vec.push(filter_matrix[i][j]);
            }
            matrix.push(vec.clone());
        }

        Filter_matrix {
            matrix: matrix,
            extra_value: extra_value,
        }
    }

    pub fn create_matrix_7x7(filter_matrix: [[i16; 7]; 7], extra_value: f32) -> Filter_matrix {
        let mut matrix: Vec<Vec<i16>> = Vec::new();

        for i in 0..7 {
            let mut vec: Vec<i16> = Vec::new();
            for j in 0..7 {
                vec.push(filter_matrix[i][j]);
            }
            matrix.push(vec.clone());
        }

        Filter_matrix {
            matrix: matrix,
            extra_value: extra_value,
        }
    }
}
